==> dtk6declarative-debug-6.0.10-1-x86_64.pkg.tar.zst: usr/src/debug/dtk6declarative/dtk6declarative/chameleon/.rcc/qmlcache/qtquickcontrolschameleonstyleplugin_DelayButton_qml.cpp <==
// /Chameleon/DelayButton.qml
#include <QtQml/qqmlprivate.h>
namespace QmlCacheGeneratedCode {
namespace _0x5f_Chameleon_DelayButton_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x3f,0x0,0x0,0x0,0x0,0x7,0x6,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe8,0x1,0x0,0x0,0x30,0x64,0x64,0x65,
0x39,0x34,0x61,0x35,0x34,0x31,0x38,0x36,
0x61,0x31,0x34,0x30,0x31,0x66,0x66,0x32,
0x31,0x39,0x65,0x36,0x34,0x32,0x32,0x37,
0x34,0x37,0x39,0x32,0x35,0x61,0x31,0x39,
0x66,0x63,0x30,0x61,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe7,0xb3,0xb7,0x48,
0xa0,0x5,0x60,0xe4,0x17,0xdc,0x63,0xbd,
0xae,0x5b,0x7,0xa,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x68,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x1,0x0,0x0,0x18,0x1,0x0,0x0,
0x20,0x1,0x0,0x0,0x48,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x44,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x64,0x0,0x65,0x0,
0x65,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,
0x2e,0x0,0x64,0x0,0x74,0x0,0x6b,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x44,0x0,0x2e,0x0,
0x44,0x0,0x65,0x0,0x6c,0x0,0x61,0x0,
0x79,0x0,0x42,0x0,0x75,0x0,0x74,0x0,
0x74,0x0,0x6f,0x0,0x6e,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x5,0x0,0x10,0x0,
0x0,0x1,0x0,0x0,0x28,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x7,0x0,0x10,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0
};
QT_WARNING_PUSH
QT_WARNING_DISABLE_MSVC(4573)
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = { { 0, QMetaType::fromType<void>(), {}, nullptr } };QT_WARNING_POP
}
}

==> dtk6declarative-debug-6.0.19-1-x86_64.pkg.tar.zst: usr/src/debug/dtk6declarative/dtk6declarative/chameleon/.rcc/qmlcache/qtquickcontrolschameleonstyleplugin_DelayButton_qml.cpp <==
// /Chameleon/DelayButton.qml
#include <QtQml/qqmlprivate.h>
namespace QmlCacheGeneratedCode {
namespace _0x5f_Chameleon_DelayButton_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x42,0x0,0x0,0x0,0x0,0x8,0x6,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe8,0x1,0x0,0x0,0x32,0x38,0x38,0x34,
0x63,0x36,0x30,0x31,0x32,0x34,0x32,0x66,
0x30,0x33,0x30,0x33,0x30,0x37,0x61,0x35,
0x61,0x63,0x64,0x63,0x61,0x39,0x38,0x34,
0x62,0x33,0x61,0x61,0x30,0x64,0x33,0x34,
0x65,0x30,0x36,0x34,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe7,0xb3,0xb7,0x48,
0xa0,0x5,0x60,0xe4,0x17,0xdc,0x63,0xbd,
0xae,0x5b,0x7,0xa,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x68,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x1,0x0,0x0,0x18,0x1,0x0,0x0,
0x20,0x1,0x0,0x0,0x48,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x44,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x64,0x0,0x65,0x0,
0x65,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,
0x2e,0x0,0x64,0x0,0x74,0x0,0x6b,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x44,0x0,0x2e,0x0,
0x44,0x0,0x65,0x0,0x6c,0x0,0x61,0x0,
0x79,0x0,0x42,0x0,0x75,0x0,0x74,0x0,
0x74,0x0,0x6f,0x0,0x6e,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x5,0x0,0x10,0x0,
0x0,0x1,0x0,0x0,0x28,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x7,0x0,0x10,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0
};
QT_WARNING_PUSH
QT_WARNING_DISABLE_MSVC(4573)
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = { { 0, 0, nullptr, nullptr } };
QT_WARNING_POP
}
}
